==> jc-1.4.0.tar.gz: soot/dava/internal/javaRep/DStaticFieldRef.h <==
// public class soot.dava.internal.javaRep.DStaticFieldRef

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 55b14250cafb5dfd soot_dava_internal_javaRep_DStaticFieldRef
// @dep_class 481d0bb0a59d7420 soot_jimple_StaticFieldRef

// header file dependencies
// @dep_header soot_jimple_StaticFieldRef

#include "soot/jimple/StaticFieldRef.h"

#ifndef _JC_soot_dava_internal_javaRep_DStaticFieldRef_H_
#define _JC_soot_dava_internal_javaRep_DStaticFieldRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootField$object;
struct _jc_soot_UnitPrinter$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_refs	_jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_nonrefs	_jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$refs	_jc_soot_dava_internal_javaRep_DStaticFieldRef$refs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$nonrefs	_jc_soot_dava_internal_javaRep_DStaticFieldRef$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object	_jc_soot_dava_internal_javaRep_DStaticFieldRef$object;

typedef const struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$vmethods	_jc_soot_dava_internal_javaRep_DStaticFieldRef$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$vtable	_jc_soot_dava_internal_javaRep_DStaticFieldRef$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$vtype	_jc_soot_dava_internal_javaRep_DStaticFieldRef$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DStaticFieldRef$method$_init$266866e5eacc6c7e(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object *, struct _jc_soot_SootField$object *, struct _jc_java_lang_String$object *);
extern void _jc_soot_dava_internal_javaRep_DStaticFieldRef$method$_init$d6230af6011a8b22(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object *, struct _jc_soot_SootField$object *, jboolean);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DStaticFieldRef$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object *);
extern void _jc_soot_dava_internal_javaRep_DStaticFieldRef$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DStaticFieldRef$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DStaticFieldRef$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_StaticFieldRef$vmethods	soot_jimple_StaticFieldRef;
	_jc_soot_dava_internal_javaRep_DStaticFieldRef$vmethods	soot_dava_internal_javaRep_DStaticFieldRef;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DStaticFieldRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$refs {
    _jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_refs	soot_dava_internal_javaRep_DStaticFieldRef;
    _jc_soot_jimple_StaticFieldRef$sub_refs	soot_jimple_StaticFieldRef;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_nonrefs {
	jboolean	supressDeclaringClass;
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_StaticFieldRef$sub_nonrefs	soot_jimple_StaticFieldRef;
    _jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_nonrefs	soot_dava_internal_javaRep_DStaticFieldRef;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object {
	_jc_soot_dava_internal_javaRep_DStaticFieldRef$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DStaticFieldRef$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DStaticFieldRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DStaticFieldRef$vtype _jc_soot_dava_internal_javaRep_DStaticFieldRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DStaticFieldRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DStaticFieldRef$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DStaticFieldRef_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/javaRep/DStaticFieldRef.h <==
// public class soot.dava.internal.javaRep.DStaticFieldRef

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 55b14250cafb5dfd soot_dava_internal_javaRep_DStaticFieldRef
// @dep_class 481d0bb0a59d7420 soot_jimple_StaticFieldRef

// header file dependencies
// @dep_header soot_jimple_StaticFieldRef

#include "soot/jimple/StaticFieldRef.h"

#ifndef _JC_soot_dava_internal_javaRep_DStaticFieldRef_H_
#define _JC_soot_dava_internal_javaRep_DStaticFieldRef_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootField$object;
struct _jc_soot_UnitPrinter$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_refs	_jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_nonrefs	_jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$refs	_jc_soot_dava_internal_javaRep_DStaticFieldRef$refs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$nonrefs	_jc_soot_dava_internal_javaRep_DStaticFieldRef$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object	_jc_soot_dava_internal_javaRep_DStaticFieldRef$object;

typedef const struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$vmethods	_jc_soot_dava_internal_javaRep_DStaticFieldRef$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$vtable	_jc_soot_dava_internal_javaRep_DStaticFieldRef$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$vtype	_jc_soot_dava_internal_javaRep_DStaticFieldRef$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DStaticFieldRef$method$_init$266866e5eacc6c7e(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object *, struct _jc_soot_SootField$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_javaRep_DStaticFieldRef$method$_init$d6230af6011a8b22(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object *, struct _jc_soot_SootField$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DStaticFieldRef$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_javaRep_DStaticFieldRef$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DStaticFieldRef$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DStaticFieldRef$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_StaticFieldRef$vmethods	soot_jimple_StaticFieldRef;
	_jc_soot_dava_internal_javaRep_DStaticFieldRef$vmethods	soot_dava_internal_javaRep_DStaticFieldRef;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DStaticFieldRef$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$refs {
    _jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_refs	soot_dava_internal_javaRep_DStaticFieldRef;
    _jc_soot_jimple_StaticFieldRef$sub_refs	soot_jimple_StaticFieldRef;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_nonrefs {
	jboolean	supressDeclaringClass;
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_StaticFieldRef$sub_nonrefs	soot_jimple_StaticFieldRef;
    _jc_soot_dava_internal_javaRep_DStaticFieldRef$sub_nonrefs	soot_dava_internal_javaRep_DStaticFieldRef;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DStaticFieldRef$object {
	_jc_soot_dava_internal_javaRep_DStaticFieldRef$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DStaticFieldRef$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DStaticFieldRef$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DStaticFieldRef$vtype _jc_soot_dava_internal_javaRep_DStaticFieldRef$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DStaticFieldRef, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DStaticFieldRef$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DStaticFieldRef_H_ */
